==> hindent-5.2.4.1-1-i686.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.4.1
id: hindent-5.2.4.1-LGpGmHjnK2rAuoucpNYxfd
key: hindent-5.2.4.1-LGpGmHjnK2rAuoucpNYxfd
license: BSD3
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
exposed: True
indefinite: False
exposed-modules:
    HIndent HIndent.Pretty HIndent.Types
abi: 32439a079b21fbce96f31586a12205e7
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hindent-5.2.4.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hindent-5.2.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.4.1-LGpGmHjnK2rAuoucpNYxfd
depends:
    base-4.10.0.0 containers-0.5.10.2
    haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR
    monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 bytestring-0.10.8.2
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m transformers-0.5.2.0
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    yaml-0.8.23.3-2QGOHBHHpaurEGLPcLVJG
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR=ac9b27fa2ca0fe7a0941d00fbc5a411d
             monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3=54591a587aa7d5d988ebd34e65b8f537
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             yaml-0.8.23.3-2QGOHBHHpaurEGLPcLVJG=2c546b36221194a2b134d5137464910f
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.2.4.1-2-i686.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.4.1
id: hindent-5.2.4.1-4Kj6tttlFn7HpUNc05CIgY
key: hindent-5.2.4.1-4Kj6tttlFn7HpUNc05CIgY
license: BSD3
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
exposed: True
indefinite: False
exposed-modules:
    HIndent HIndent.Pretty HIndent.Types
abi: a17f017bc92ceb01945d756fe07d3ad8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hindent-5.2.4.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hindent-5.2.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.4.1-4Kj6tttlFn7HpUNc05CIgY
depends:
    base-4.10.0.0 containers-0.5.10.2
    haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR
    monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 bytestring-0.10.8.2
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m transformers-0.5.2.0
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    yaml-0.8.24-2wdOOQKc6Dt63OCZo8Nf1H
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR=ac9b27fa2ca0fe7a0941d00fbc5a411d
             monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3=54591a587aa7d5d988ebd34e65b8f537
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             yaml-0.8.24-2wdOOQKc6Dt63OCZo8Nf1H=f3316d9da6e6607f19b5fc76111163c2
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
